@@ -96,9 +96,9 @@ def assert_alignment(align: str) -> None:
     :param align: Align value
     :return: None
     """
-    assert isinstance(align, str), 'alignment "{0}" must be a string'.format(align)
+    assert isinstance(align, str), f'alignment "{align}" must be a string'
     assert align in (ALIGN_LEFT, ALIGN_CENTER, ALIGN_RIGHT), \
-        'incorrect alignment value "{0}"'.format(align)
+        f'incorrect alignment value "{align}"'
 
 
 def assert_color(
@@ -114,23 +114,20 @@ def assert_color(
     """
     color = format_color(color, warn_if_invalid=warn_if_invalid)
     assert isinstance(color, VectorInstance), \
-        'color must be a tuple or list, not type "{0}"'.format(type(color))
+        f'color must be a tuple or list, not type "{type(color)}"'
     assert 4 >= len(color) >= 3, \
         'color must be a tuple or list of 3 or 4 numbers'
     for i in range(3):
         assert isinstance(color[i], int), \
-            '"{0}" in element color {1} must be an integer, not type "{2}"' \
-            ''.format(color[i], color, type(color))
+            f'"{color[i]}" in element color {color} must be an integer, not type "{type(color)}"'
         assert 0 <= color[i] <= 255, \
-            '"{0}" in element color {1} must be an integer between 0 and 255' \
-            ''.format(color[i], color)
+            f'"{color[i]}" in element color {color} must be an integer between 0 and 255'
     if len(color) == 4:
         assert isinstance(color[3], int), \
-            'alpha channel must be an integer between 0 and 255, not type "{0}"' \
-            ''.format(type(color))
+            f'alpha channel must be an integer between 0 and 255, not type "{type(color)}"'
         assert 0 <= color[3] <= 255, \
-            'opacity of color {0} must be an integer between 0 and 255; where ' \
-            '0 is fully-transparent and 255 is fully-opaque'.format(color)
+            f'opacity of color {color} must be an integer between 0 and 255; ' \
+            f'where 0 is fully-transparent and 255 is fully-opaque'
     return color
 
 
@@ -156,7 +153,7 @@ def assert_list_vector(list_vector: Union[List[Vector2NumberType], Tuple[Vector2
     :return: None
     """
     assert isinstance(list_vector, VectorInstance), \
-        'list_vector "{0}" must be a tuple or list'.format(list_vector)
+        f'list_vector "{list_vector}" must be a tuple or list'
     for v in list_vector:
         assert_vector(v, length)
 
@@ -169,9 +166,9 @@ def assert_orientation(orientation: str) -> None:
     :return: None
     """
     assert isinstance(orientation, str), \
-        'orientation "{0}" must be a string'.format(orientation)
+        f'orientation "{orientation}" must be a string'
     assert orientation in (ORIENTATION_HORIZONTAL, ORIENTATION_VERTICAL), \
-        'invalid orientation value "{0}"'.format(orientation)
+        f'invalid orientation value "{orientation}"'
 
 
 def assert_position(position: str) -> None:
@@ -182,11 +179,11 @@ def assert_position(position: str) -> None:
     :return: None
     """
     assert isinstance(position, str), \
-        'position "{0}" must be a string'.format(position)
+        f'position "{position}" must be a string'
     assert position in (POSITION_WEST, POSITION_SOUTHWEST, POSITION_SOUTH,
                         POSITION_SOUTHEAST, POSITION_EAST, POSITION_NORTH,
                         POSITION_NORTHWEST, POSITION_NORTHEAST, POSITION_CENTER), \
-        'invalid position value "{0}"'.format(position)
+        f'invalid position value "{position}"'
 
 
 def assert_position_vector(position: Union[str, List[str], Tuple[str, ...]]) -> None:
@@ -222,19 +219,17 @@ def assert_vector(
     :return: None
     """
     assert isinstance(num_vector, VectorInstance), \
-        'vector "{0}" must be a list or tuple of {1} items if type {2}' \
-        ''.format(num_vector, length, instance)
+        f'vector "{num_vector}" must be a list or tuple of {length} items if type {instance}'
     if length != 0:
         assert len(num_vector) == length, \
-            'vector "{0}" must contain {1} numbers only, ' \
-            'but {2} were given'.format(num_vector, length, len(num_vector))
+            f'vector "{num_vector}" must contain {length} numbers only, ' \
+            f'but {num_vector} were given'
     for i in range(len(num_vector)):
         num = num_vector[i]
         if instance == int and isinstance(num, float) and int(num) == num:
             num = int(num)
         assert isinstance(num, instance), \
-            'item {0} of vector must be {1}, not type "{2}"' \
-            ''.format(num, instance, type(num))
+            f'item {num} of vector must be {instance}, not type "{type(num)}"'
 
 
 def check_key_pressed_valid(event: EventType) -> bool:
@@ -345,7 +340,7 @@ def format_color(
                 c = pygame.Color(color)
         except ValueError:
             if warn_if_invalid:
-                warn('invalid color value "{0}"'.format(color))
+                warn(f'invalid color value "{color}"')
             else:
                 raise
             return color
@@ -427,14 +422,12 @@ def load_pygame_image_file(image_path: str, **kwargs) -> 'pygame.Surface':
                     img_pil.tobytes(), img_pil.size, img_pil.mode).convert()
 
             except (ModuleNotFoundError, ImportError):
-                warn('Image file "{0}" could not be loaded, as pygame.error is '
-                     'raised. To avoid this issue install the Pillow library'
-                     ''.format(image_path))
+                warn(f'Image file "{image_path}" could not be loaded, as pygame.error '
+                     f'is raised. To avoid this issue install the Pillow library')
                 raise
 
             except pil_invalid_exception:
-                warn('The image "{0}" could not be loaded using Pillow'
-                     ''.format(image_path))
+                warn(f'The image "{image_path}" could not be loaded using Pillow')
                 raise
 
         else:
@@ -505,7 +498,7 @@ def parse_padding(padding: PaddingType) -> Tuple4IntType:
 
     if isinstance(padding, NumberInstance):
         assert padding >= 0, 'padding cannot be a negative number'
-        return padding, padding, padding, padding
+        return int(padding), int(padding), int(padding), int(padding)
     else:
         assert 1 <= len(padding) <= 4, 'padding must be a tuple of 2, 3 or 4 elements'
         for i in range(len(padding)):
@@ -560,7 +553,7 @@ def print_menu_widget_structure(
         d = current_depth - depth
         for i in range(d):
             j = depth + d - (i + 1)  # Current depth
-            line = '·   {0}└{1}'.format('│   ' * j, '┄' * 3)  # * depth_widths[j]
+            line = f'·   {"│   " * j}└{"┄" * 3}'  # * depth_widths[j]
             print(c.BRIGHT_WHITE + line.ljust(0, '━') + c.ENDC)  # 80 also work
 
     non_menu_frame_widgets: Dict[int, List['pygame_menu.widgets.Widget']] = {}
@@ -608,7 +601,7 @@ def print_menu_widget_structure(
                     else:
                         prev_indx = widgets.index(jw)
         except ValueError as e:
-            print('[ERROR] while requesting widget {0}'.format(jw.get_class_id()))
+            print(f'[ERROR] while requesting widget {jw.get_class_id()}')
             warn(str(e))
         indx += 1
     process_non_menu_frame(indx)
@@ -627,7 +620,7 @@ def set_pygame_cursor(cursor: CursorInputType) -> None:
             # noinspection PyArgumentList
             pygame.mouse.set_cursor(cursor)
     except (pygame.error, TypeError):
-        warn('could not establish widget cursor, invalid value {0}'.format(cursor))
+        warn(f'could not establish widget cursor, invalid value {cursor}')
 
 
 def uuid4(short: bool = False) -> str:
@@ -686,7 +679,7 @@ def widget_terminal_title(
     w_class_id = TerminalColors.BOLD + widget.get_class_id() + TerminalColors.ENDC
     if isinstance(widget, pygame_menu.widgets.Frame):
         w_title = TerminalColors.BRIGHT_WHITE + '┌━' + TerminalColors.ENDC
-        w_title += '{0} - {3}[{1},{2},'.format(w_class_id, *widget.get_indices(), TerminalColors.LGREEN)
+        w_title += f'{0} - {3}[{1},{2},'.format(w_class_id, *widget.get_indices(), TerminalColors.LGREEN)
         if widget.horizontal:
             w_title += 'H] '
         else:
@@ -694,14 +687,14 @@ def widget_terminal_title(
         if widget.is_scrollable:
             wsz = widget.get_inner_size()
             wsm = widget.get_max_size()
-            wsh = wsm[0] if wsm[0] == wsz[0] else '{0}→{1}'.format(wsm[0], wsz[0])
-            wsv = wsm[1] if wsm[1] == wsz[1] else '{0}→{1}'.format(wsm[1], wsz[1])
-            w_title += '∑ [{0},{1}] '.format(wsh, wsv)
+            wsh = wsm[0] if wsm[0] == wsz[0] else f'{wsm[0]}→{wsz[0]}'
+            wsv = wsm[1] if wsm[1] == wsz[1] else f'{wsm[1]}→{wsz[1]}'
+            w_title += f'∑ [{wsh},{wsv}] '
         w_title += TerminalColors.ENDC
     else:
         if widget.get_title() != '':
             title_f = TerminalColors.UNDERLINE + widget.get_title() + TerminalColors.ENDC
-            w_title = '{0} - {1} - '.format(w_class_id, title_f)
+            w_title = f'{w_class_id} - {title_f} - '
         else:
             w_title = w_class_id + ' - '
 
@@ -732,7 +725,7 @@ def widget_terminal_title(
     if widget.is_selected():
         w_title += TerminalColors.BOLD + ' ⟵'
         if current_index != -1 and current_index != widget_index:
-            w_title += '! [{0}->{1}]'.format(widget_index, current_index)
+            w_title += f'! [{widget_index}->{current_index}]'
     if widget.get_menu() is None:
         w_title += ' !▲'
     w_title += TerminalColors.ENDC
