@@ -378,8 +378,7 @@ class DropSelect(Widget):
         from pygame_menu._scrollarea import get_scrollbars_from_position
 
         if not self.configured:
-            raise RuntimeError('{0} must be configured before creating selection drop'
-                               ''.format(self.get_class_id()))
+            raise RuntimeError(f'{self.get_class_id()} must be configured before creating selection drop')
 
         # Create options buttons
         total_height = 0
@@ -989,7 +988,7 @@ class DropSelect(Widget):
                     found = True
                     break
             if not found:
-                raise ValueError('no value "{}" found in drop select'.format(item))
+                raise ValueError(f'no value "{item}" found in drop select')
         elif isinstance(item, int):
             assert -1 <= item < len(self._items), \
                 'item index must be greater than zero and lower than the number ' \
@@ -1048,8 +1047,8 @@ class DropSelect(Widget):
         """
         if self._drop_frame is None:
             raise _SelectionDropNotMadeException(
-                'selection drop has not been made yet. Call {0}._make_selection_drop()'
-                'for avoiding this exception'.format(self.get_class_id())
+                f'selection drop has not been made yet. Call {self.get_class_id()}'
+                f'._make_selection_drop() for avoiding this exception'
             )
 
     def get_items(self) -> Union[List[Tuple[Any, ...]], List[str]]:
@@ -1100,11 +1099,9 @@ class DropSelect(Widget):
         h -= self._menu.get_menubar().get_height()
         bw, bh = self._selection_box_width, self._drop_frame.get_attribute('height')
         assert w >= bw, \
-            'selection box width ({0}) cannot be greater than menu width ({1})' \
-            ''.format(bw, w)
+            f'selection box width ({bw}) cannot be greater than menu width ({w})'
         assert h >= bh, \
-            'selection box height ({0}) cannot be greater than menu height ({1})' \
-            ''.format(bh, h)
+            f'selection box height ({bh}) cannot be greater than menu height ({h})'
         x = (w - bw) / 2 + offx
         y = (h - bh) / 2 + offy
         return x, y
